#!/bin/bash
echo '###############'
echo '#Install Patch#'
echo '###############'
cd /home/ajin/postgres/Synchronisation/postgres
make install;

echo '##########'
echo '#Clean up#'
echo '##########'

pg_ctl stop -D /home/ajin/ajin-setup/dataoss -w
pg_ctl stop -D /home/ajin/ajin-setup/dataoss2 -w
pg_ctl stop -D /home/ajin/ajin-setup/standbydb -w

rm -Rf /home/ajin/ajin-setup/dataoss/*
rm -Rf /home/ajin/ajin-setup/dataoss2/*
rm -Rf /home/ajin/ajin-setup/standbydb/*

echo '########'
echo '#Set up#'
echo '########'

initdb -D /home/ajin/ajin-setup/dataoss -U postgres

cat << EOF >> /home/ajin/ajin-setup/dataoss/postgresql.conf
port=6972
wal_level = logical
standby_slot_names = 'standby_test'
shared_buffers = 40GB
max_worker_processes = 32
max_parallel_maintenance_workers = 24
max_parallel_workers = 32
synchronous_commit = off
checkpoint_timeout = 1d
max_wal_size = 24GB
min_wal_size = 15GB
autovacuum = off
EOF

# Boot a database instance

pg_ctl -D /home/ajin/ajin-setup/dataoss start -w -l /home/ajin/ajin-setup/dataoss/logfile

sleep 1

(
    echo -e "CREATE ROLE replication WITH REPLICATION PASSWORD 'password' LOGIN;"
	echo -e "SELECT pg_create_physical_replication_slot('standby_test');"
) | psql -U postgres -p 6972

pg_basebackup -h 127.0.0.1 -D /home/ajin/ajin-setup/standbydb  -R -P -U replication -X s  -p 6972

# Update dbname in conf. 
sed -i "s/user=replication/dbname=postgres user=replication/" "/home/ajin/ajin-setup/standbydb/postgresql.auto.conf"
echo "Auto conf updated successfully."

cat << EOF >> /home/ajin/ajin-setup/standbydb/postgresql.conf
port=6974
wal_level = logical
shared_buffers = 40GB
sync_replication_slots = true
primary_slot_name = 'standby_test'
hot_standby_feedback = on
max_worker_processes = 32
max_parallel_maintenance_workers = 24
max_parallel_workers = 32
synchronous_commit = off
checkpoint_timeout = 1d
max_wal_size = 24GB
min_wal_size = 15GB
autovacuum = off
EOF
pg_ctl -D /home/ajin/ajin-setup/standbydb start -w -l /home/ajin/ajin-setup/standbydb/logfile

sleep 1

initdb -D /home/ajin/ajin-setup/dataoss2 -U postgres

cat << EOF >> /home/ajin/ajin-setup/dataoss2/postgresql.conf
port=6973
wal_level = logical
shared_buffers = 40GB
max_worker_processes = 32
max_parallel_maintenance_workers = 24
max_parallel_workers = 32
synchronous_commit = off
checkpoint_timeout = 1d
max_wal_size = 24GB
min_wal_size = 15GB
autovacuum = off
EOF

pg_ctl -D /home/ajin/ajin-setup/dataoss2 start -w -l /home/ajin/ajin-setup/dataoss2/logfile

sleep 1

pgbench postgres -p 6972 -U postgres -qis 2

pg_dump -U postgres -F c -p 6972 -t pgbench_accounts -t pgbench_branches -t pgbench_history -t pgbench_tellers | pg_restore -U postgres -1 -p 6973 -d postgres
(
    echo -e "CREATE publication pub for ALL tables;"
) | psql -U postgres -p 6972

(
    echo -e "truncate pgbench_accounts;"
	echo -e "truncate pgbench_branches;"
	echo -e "truncate pgbench_history;"
	echo -e "truncate pgbench_tellers;"
) | psql -U postgres -p 6973

(
	echo -e "CREATE SUBSCRIPTION sub CONNECTION 'dbname=postgres user=postgres host=localhost port=6972' PUBLICATION pub with (failover=true);"
) | psql -U postgres -p 6973

cat << EOF >> /home/ajin/ajin-setup/dataoss/postgresql.conf
synchronous_commit on
synchronous_standby_names = 'sub'
EOF
pg_ctl -D /home/ajin/ajin-setup/dataoss -w -l /home/ajin/ajin-setup/dataoss/logfile restart
echo "Primary synchronous commit enabled"

sleep 5

pgbench postgres -p 6972 -U postgres -c 10 -j 3 -T 900 -P 5

echo "Test complete"




